// itsp 13.00-

capt program drop _all
mata: mata clear

type varextrema.ado

do calcextrema.mata

type calcextrema.mata

sysuse auto, clear
varextrema price if foreign
return list

/*
*! centervars 1.0.1  CFBaum 08oct2007
program centervars, rclass
   version 10.1
   syntax varlist(numeric) [if] [in]
   marksample touse
   quietly count if `touse'
   if `r(N)' == 0  error 2000
   mata: centerv("`varlist'", "`touse'")
end

version 10.1
mata:
void centerv(string scalar varlist, ///
              string scalar touse)
{
  st_view(X=., ., tokens(varlist), touse)
  X[ , ] = X:- mean(X)
}
end



sysuse auto, clear
centervars price mpg
summarize price mpg
*/

program drop _all
mata: mata clear

type centervars.ado

/*
*! centervars 1.0.0  CFBaum 08oct2007
program centervars, rclass
   version 10.1
   syntax varlist(numeric) [if] [in], GENerate(string) [DOUBLE]
   marksample touse
   quietly count if `touse'
   if `r(N)' == 0  error 2000
   foreach v of local varlist {
       confirm new var `generate'`v'
       generate `double' `generate'`v' = .
       local newvars "`newvars' `generate'`v'"
   }
   mata: centerv("`varlist'", "`newvars'", "`touse'")
end
*/
/*
version 10.1
mata:
void centerv(string scalar varlist, ///
              string scalar newvarlist,
              string scalar touse)
{
  st_view(X=., ., tokens(varlist), touse)
  st_view(Z=., ., tokens(newvarlist), touse)
  Z[ , ] = X:- mean(X)
}
end
*/
type centerv.mata

do centerv.mata

sysuse auto, clear
centervars price mpg, gen(c_)
centervars price mpg if foreign, gen(cf_) double
summarize c*


program drop _all
mata: mata clear
type avgper.ado


type avgper.mata

/*
*! avgper 1.0.0  CFBaum 08oct2007
program avgper, rclass
	version 10.1
	syntax varlist(max=1 numeric) [if] [in], per(integer)
// honor if and in conditions if provided
	marksample touse
	quietly count if `touse'
    if `r(N)' == 0 {
       error 2000
    }
	local newvar = "`varlist'" + "A" + string(`per')
	quietly generate `newvar' = .
* pass the varname and newvarname to Mata
	mata: avgper("`varlist'", "`newvar'",  `per', "`touse'")
	end
*/

/*
version 10.1
mata:
	void avgper(string scalar vname,
            string scalar newvname,
	            real scalar per,
	            string scalar touse)
	{      
        real matrix v1, v3
	st_view(v1=., ., vname, touse)
	st_view(v2=., ., newvname)
	v3 = colshape(v1',per) * J(per, 1, 1/per)
	v2[(1::rows(v3)),] = v3
	}
end
*/

do avgper.mata
use urates, clear
tsset
avgper tenn, per(3)  // calculate quarterly averages
avgper tenn, per(12) // calculate annual averages
summarize tenn*

tsmktim quarter, start(1978q1) // create quarterly calendar var
tsmktim year, start(1978)      // create annual calendar var
list t tenn quarter tennA3 year tennA12 in 1/12, sep(3)


use urates, clear
foreach v of varlist tenn-arkansas {
	avgper `v', per(3)
}
summarize tenn-arkansasA3, sep(6)

type aggreg.ado
/*
program aggreg, rclass
	version 10.1
	syntax varlist(max=1 numeric) [if] [in], per(integer) [func(string)]
	marksample touse
	quietly count if `touse'
	if `r(N)' == 0 {
	        error 2000
	}
* validate per versus selected sample
	if `per' <= 0 | `per' >= `r(N)' {
		display as error "per must be > 0 and < N of observations."
		error 198
	}
	if mod(`r(N)',`per' != 0) {
		display as error "N of observations must be a multiple of per."
		error 198
	}
* validate func option; default is average (code A)
    local ops A S F L
    local opnames average sum first last
    if "`func'" == "" {
    	local op "A"
    }
    else {
    	local nop : list posof "`func'" in opnames
    	if !`nop' {
    		display as err "Error: func must be chosen from `opnames'"
    		error 198
    	}
    	local op : word `nop' of `ops'
    }
* validate the new varname
	local newvar = "`varlist'`op'`per'"
     quietly generate `newvar' = .
* pass the varname and newvarname to Mata
	mata: aggreg("`varlist'", "`newvar'",  `per', "`op'", "`touse'")
	end
*/
do aggreg.mata

type aggreg.mata

/*
version 10.1
mata:
void aggreg(string scalar vname,
            string scalar newvname,
	            real scalar per,
	        string scalar op,
	            string scalar touse)
	{
	real colvector mult
	if (op=="A") {
	     mult = J(per, 1, 1/per)
	}
	else if (op=="S") {
	     mult = J(per, 1, 1)
	}
	else if (op=="F") {
		 mult = J(per, 1, 0)
		 mult[1] = 1
	}
	else if (op=="L") {
	     mult = J(per, 1, 0)
	     mult[per] = 1
	}
	st_view(v1=., ., vname, touse)
	st_view(v2=., ., newvname)
	v3 = colshape(v1', per) * mult
	v2[(1::rows(v3)),] = v3
	}
end
*/

* webuse urates, clear
clear

use urates, clear
aggreg tenn, per(3)  // calculate quarterly averages
aggreg tenn, per(3) func(sum) // calculate quarterly sum
aggreg tenn, per(3) func(first) // extract first month's value
aggreg tenn, per(3) func(last) // extract first month's value
tsmktim quarter, start(1978q1) // create quarterly calendar var
list t tenn quarter tennA3 tennS3 tennF3 tennL3 in 1/12, sep(3)

/*
// save the compiled averageper function 
mata: mata mosave averageper(), replace
*/

do gbpval.mata

type gbpval.mata

do gbpval2.mata

type gbpval2.mata

do gbpval3.mata

type gbpval3.mata
